@@ -9,7 +9,7 @@ pub struct Asset {
     relative_path: &'static str,
 }
 
-pub fn main() {
+fn main() {
     use base::examples::assets;
 
     assert_eq!(assets::CREDITS_MD.contents_bytes, "Boo Far\n".as_bytes());
