@@ -1,6 +1,6 @@
-//! Include file data from many files in your Rust code for self-contained binaries.
+//! Include many files in your Rust code for self-contained binaries.
 //!
-//! ![test](https://github.com/evolutics/iftree/actions/workflows/test.yml/badge.svg)
+//! ![Test](https://github.com/evolutics/iftree/actions/workflows/test.yml/badge.svg)
 //! [![crates.io](https://img.shields.io/crates/v/iftree.svg)](https://crates.io/crates/iftree)
 //!
 //! # Motivation
@@ -11,11 +11,12 @@
 //! The standard library's `std::include_str!` includes the contents of a given
 //! file. Iftree generalizes this in two ways:
 //!
-//! 1. Not just one, but many files can be included at once with **path patterns**
-//!    in a `.gitignore`-like format. Patterns are flexible: you can skip hidden
-//!    files, filter by filename extension, select a fixed list of files, etc.
-//! 1. Instead of including the file contents only, files can be associated with
-//!    **any data** fields such as additional file metadata.
+//! - Not just one, but many files can be included at once with **path patterns** in
+//!   a `.gitignore`-like format. Patterns are flexible: you can include multiple
+//!   folders, skip hidden files, filter by filename extension, select a fixed file
+//!   list, etc.
+//! - Instead of including the file contents only, files can be associated with
+//!   **any data** fields such as additional file metadata.
 //!
 //! Conceptually:
 //!
@@ -51,7 +52,7 @@
 //! // The standard field `contents_str` is automatically populated with a call to
 //! // `include_str!`, but you can plug in your own initializer.
 //!
-//! pub fn main() {
+//! fn main() {
 //!     // Based on this, Iftree generates an array `ASSETS` with the desired file
 //!     // data. You can use it like so:
 //!     assert_eq!(ASSETS.len(), 3);
@@ -73,7 +74,7 @@
 //!
 //! ## Getting started
 //!
-//! 1. Add the **dependency** `iftree = "0.1"` to your manifest (`Cargo.toml`).
+//! 1. Add the **dependency** `iftree = "1.0"` to your manifest (`Cargo.toml`).
 //!
 //! 1. Define your **asset type** (`MyAsset` in the [introduction](#introduction)).
 //!
@@ -117,9 +118,9 @@
 //!
 //! ## Standard fields
 //!
-//! When you use fields from the following list only, an initializer for your asset
-//! type is generated without further configuration. You can still override these
-//! field names with a [custom initializer](#templateinitializer).
+//! When you use a subset of the following fields only, an initializer for your
+//! asset type is generated without further configuration. You can still override
+//! these field names with a [custom initializer](#templateinitializer).
 //!
 //! - **`contents_bytes:`** `&'static [u8]`
 //!
@@ -154,31 +155,41 @@
 //! - **`relative_path:`** `&'static str`
 //!
 //!   File path relative to the base folder, which is the folder with your manifest
-//!   (`Cargo.toml`) by default.
+//!   (`Cargo.toml`) by default. Path components are separated by a slash `/`,
+//!   independent of your platform.
 //!
 //! See
 //! [example](https://github.com/evolutics/iftree/blob/main/examples/basics_standard_fields.rs).
 //!
 //! ## Name sanitization
 //!
-//! When generating identifiers based on paths, names are sanitized as follows to
-//! ensure they are
-//! [valid identifiers](https://doc.rust-lang.org/reference/identifiers.html):
+//! When generating identifiers based on paths, names are sanitized. For example, a
+//! filename `404_not_found.md` is sanitized to an identifier `_404_NOT_FOUND_MD`.
 //!
-//! - Characters other than ASCII alphanumericals are replaced by `"_"`.
-//! - If the first character is numeric, then `"_"` is prepended.
-//! - If the name is `"_"`, `"crate"`, `"self"`, `"Self"`, or `"super"`, then `"_"`
-//!   is appended.
+//! The sanitization process is designed to generate valid
+//! [Unicode identifiers](https://doc.rust-lang.org/nightly/reference/identifiers.html).
+//! Essentially, it replaces invalid identifier characters by underscores `"_"`.
 //!
-//! Names are further adjusted to respect naming conventions in the default case:
+//! More precisely, these transformations are applied in order:
 //!
-//! - Lowercase for folders (because they map to module names).
-//! - Uppercase for filenames (because they map to static variables).
+//! 1. The case of letters is adjusted to respect naming conventions:
+//!    - All lowercase for folders (because they map to module names).
+//!    - All uppercase for filenames (because they map to static variables).
+//! 1. Characters without the property `XID_Continue` are replaced by `"_"`. The set
+//!    of `XID_Continue` characters in ASCII is `[0-9A-Z_a-z]`.
+//! 1. If the first character does not belong to `XID_Start` and is not `"_"`, then
+//!    `"_"` is prepended. The set of `XID_Start` characters in ASCII is `[A-Za-z]`.
+//! 1. If the name is `"_"`, `"crate"`, `"self"`, `"Self"`, or `"super"`, then `"_"`
+//!    is appended.
+//!
+//! Note that non-ASCII identifiers are only supported from Rust 1.53.0. For earlier
+//! versions, the sanitization here may generate invalid identifiers if you use
+//! non-ASCII paths, in which case you need to manually rename any affected files.
 //!
 //! ## Portable file paths
 //!
-//! To prevent issues when developing on different platforms, any paths in your
-//! configuration should follow these recommendations:
+//! To prevent issues when developing on different platforms, your file paths should
+//! follow these recommendations:
 //!
 //! - Path components are separated by a slash `/` (even on Windows).
 //! - Filenames do not contain backslashes `\` (even on Unix-like systems).
@@ -208,6 +219,7 @@
 //! - File server with [Actix Web](https://github.com/evolutics/iftree/blob/main/examples/library_actix_web.rs)
 //! - File server with [Tide](https://github.com/evolutics/iftree/blob/main/examples/library_tide.rs)
 //! - File server with [warp](https://github.com/evolutics/iftree/blob/main/examples/library_warp.rs)
+//! - Lazy initialization with [`lazy_static`](https://github.com/evolutics/iftree/blob/main/examples/library_lazy_static.rs)
 //! - Lazy initialization with [`once_cell`](https://github.com/evolutics/iftree/blob/main/examples/library_once_cell.rs)
 //! - Media types with [`mime_guess`](https://github.com/evolutics/iftree/blob/main/examples/library_mime_guess.rs)
 //! - Templates with [Handlebars](https://github.com/evolutics/iftree/blob/main/examples/library_handlebars.rs)
@@ -232,14 +244,18 @@
 //!
 //! Here is how I think Iftree compares to related projects for the given criteria.
 //!
-//! | Project                                                                            | File selection                                      | Included file data     | Data access via                                                         |
-//! | ---------------------------------------------------------------------------------- | --------------------------------------------------- | ---------------------- | ----------------------------------------------------------------------- |
-//! | [**`include_dir`**](https://github.com/Michael-F-Bryan/include_dir) 0.6            | Single folder                                       | Path, contents         | File path, nested iterators, glob patterns                              |
-//! | [**`includedir`**](https://github.com/tilpner/includedir) 0.6                      | Multiple files, multiple folders                    | Path, contents         | File path, iterator                                                     |
-//! | [**Rust Embed**](https://github.com/pyros2097/rust-embed) 5.9                      | Single folder                                       | Path, contents         | File path, iterator                                                     |
-//! | [**`std::include_bytes`**](https://doc.rust-lang.org/std/macro.include_bytes.html) | Single file                                         | Byte contents          | Literal file path                                                       |
-//! | [**`std::include_str`**](https://doc.rust-lang.org/std/macro.include_str.html)     | Single file                                         | String contents        | Literal file path                                                       |
-//! | **Iftree**                                                                         | Multiple files by inclusion-exclusion path patterns | Path, contents, custom | `base::x::y::MY_FILE` variables (constant time), `ASSETS` array, custom |
+//! | Project                                                                            | File selection                                      | Included file data     | Data access via                                                                                     |
+//! | ---------------------------------------------------------------------------------- | --------------------------------------------------- | ---------------------- | --------------------------------------------------------------------------------------------------- |
+//! | [**`include_dir`**](https://github.com/Michael-F-Bryan/include_dir) 0.6            | Single folder                                       | Path, contents         | File path, nested iterators, glob patterns                                                          |
+//! | [**`includedir`**](https://github.com/tilpner/includedir) 0.6                      | Multiple files, multiple folders                    | Path, contents         | File path, iterator                                                                                 |
+//! | [**Rust Embed**](https://github.com/pyros2097/rust-embed) 5.9                      | Single folder                                       | Path, contents         | File path, iterator                                                                                 |
+//! | [**`std::include_bytes`**](https://doc.rust-lang.org/std/macro.include_bytes.html) | Single file                                         | Contents               | File path                                                                                           |
+//! | [**`std::include_str`**](https://doc.rust-lang.org/std/macro.include_str.html)     | Single file                                         | Contents               | File path                                                                                           |
+//! | **Iftree**                                                                         | Multiple files by inclusion-exclusion path patterns | Path, contents, custom | File path (via `base::x::y::MY_FILE` variables in constant time), iterator (`ASSETS` array), custom |
+//!
+//! Generally, while Iftree has defaults to address common use cases, it can be
+//! customized to support more specific use cases, too (see [recipes](#recipes) for
+//! examples).
 //!
 //! # Configuration reference
 //!
@@ -334,7 +350,7 @@
 //!
 //! As inputs, the macro is passed the following arguments, separated by comma:
 //!
-//! 1. Relative file path as a string literal.
+//! 1. Relative file path as a string literal. Path components are separated by `/`.
 //! 1. Absolute file path as a string literal.
 //!
 //! As an output, the macro must return a
@@ -363,16 +379,19 @@
 //!
 //! - `visit_base`:
 //!   1. Total number of selected files as a `usize` literal.
-//!   1. Outputs of the visitor applied to the base folder entries.
+//!   1. Outputs of the visitor applied to the base folder entries, ordered by
+//!      filename in Unicode code point order.
 //! - `visit_folder`:
 //!   1. Folder name as a string literal.
 //!   1. [Sanitized](#name-sanitization) folder name as an identifier.
-//!   1. Outputs of the visitor applied to the folder entries.
+//!   1. Outputs of the visitor applied to the folder entries, ordered by filename
+//!      in Unicode code point order.
 //! - `visit_file`:
 //!   1. Filename as a string literal.
 //!   1. [Sanitized](#name-sanitization) filename as an identifier.
 //!   1. Zero-based index of the file among the selected files as a `usize` literal.
-//!   1. Relative file path as a string literal.
+//!   1. Relative file path as a string literal. Path components are separated by
+//!      `/`.
 //!   1. Absolute file path as a string literal.
 //!
 //! The `visit_folder` macro is optional. If missing, the outputs of the
@@ -394,8 +413,16 @@
 //!
 //! `visit_my_…` are the names of your corresponding macros.
 //!
-//! See
-//! [example](https://github.com/evolutics/iftree/blob/main/examples/configuration_template_visitors.rs).
+//! See examples:
+//!
+//! - [Basic](https://github.com/evolutics/iftree/blob/main/examples/configuration_template_visitors.rs)
+//! - [Nesting](https://github.com/evolutics/iftree/blob/main/examples/configuration_template_visitors_nesting.rs)
+//! - [Emulation of default code generation](https://github.com/evolutics/iftree/blob/main/examples/configuration_template_visitors_emulation.rs)
+//!
+//! # Further resources
+//!
+//! - [Changelog](https://github.com/evolutics/iftree/blob/main/CHANGELOG.md)
+//! - [crates.io](https://crates.io/crates/iftree)
 
 mod generate_view;
 mod go;
@@ -422,7 +449,7 @@ pub fn include_file_tree(
 
 #[cfg(test)]
 mod tests {
-    use ignore::overrides;
+    use std::fs;
 
     #[test]
     fn readme_includes_manifest_description() {
@@ -454,8 +481,7 @@ mod tests {
 
     #[test]
     fn readme_refers_to_current_manifest_version() {
-        let manifest = get_manifest();
-        let version = manifest["package"]["version"].as_str().unwrap();
+        let version = get_manifest_version();
         let major_minor_version = version.rsplitn(2, '.').nth(1).unwrap();
         let dependency = format!("`iftree = \"{}\"`", major_minor_version);
 
@@ -464,10 +490,14 @@ mod tests {
         assert!(actual);
     }
 
+    fn get_manifest_version() -> String {
+        String::from(get_manifest()["package"]["version"].as_str().unwrap())
+    }
+
     #[test]
     fn readme_links_to_each_example_exactly_once() {
         let mut actual =
-            regex::Regex::new(r"https://github.com/evolutics/iftree/blob/main/(examples/[^)]+)")
+            regex::Regex::new(r"https://github.com/evolutics/iftree/blob/main/examples/([^)]+)")
                 .unwrap()
                 .captures_iter(get_readme())
                 .map(|captures| captures.get(1).unwrap().as_str())
@@ -475,25 +505,28 @@ mod tests {
 
         actual.sort_unstable();
         let actual = actual;
-        let examples_folder = "examples";
-        let expected = ignore::WalkBuilder::new(examples_folder)
-            .standard_filters(false)
-            .overrides(
-                overrides::OverrideBuilder::new(examples_folder)
-                    .add("*.rs")
-                    .unwrap()
-                    .build()
-                    .unwrap(),
-            )
-            .sort_by_file_name(|first, second| first.cmp(second))
-            .build()
-            .map(|entry| entry.unwrap())
-            .filter(|entry| entry.metadata().unwrap().is_file())
-            .map(|entry| String::from(entry.path().to_str().unwrap()))
+        let mut expected = fs::read_dir("examples")
+            .unwrap()
+            .map(|entry| entry.unwrap().file_name().into_string().unwrap())
+            .filter(|filename| filename.ends_with(".rs"))
             .collect::<Vec<_>>();
+        expected.sort_unstable();
         assert_eq!(actual, expected);
     }
 
+    #[test]
+    fn changelog_contains_current_manifest_version() {
+        let version_section = format!("\n\n## {} – ", get_manifest_version());
+
+        let actual = get_changelog().contains(&version_section);
+
+        assert!(actual);
+    }
+
+    fn get_changelog() -> &'static str {
+        include_str!("../CHANGELOG.md")
+    }
+
     #[test]
     fn module_documentation_corresponds_to_readme() {
         let mut actual = String::from("# Iftree: Include File Tree 🌳\n\n");
