@@ -3,9 +3,8 @@ use super::get_paths;
 use super::get_raw_paths;
 use crate::model;
 use std::env;
-use std::vec;
 
-pub fn main(configuration: &model::Configuration) -> model::Result<vec::Vec<model::Path>> {
+pub fn main(configuration: &model::Configuration) -> model::Result<Vec<model::Path>> {
     let base_folder = get_base_folder::main(configuration, &|name| env::var(name))?;
     let paths = get_raw_paths::main(configuration, &base_folder)?;
     get_paths::main(base_folder, paths)
@@ -14,7 +13,7 @@ pub fn main(configuration: &model::Configuration) -> model::Result<vec::Vec<mode
 #[cfg(test)]
 mod tests {
     use super::*;
-    use std::fs;
+    use std::env;
     use std::path;
 
     #[test]
@@ -28,13 +27,14 @@ mod tests {
 
         let actual = actual.unwrap();
         let expected = vec![model::Path {
-            relative: String::from("assets/credits.md"),
-            absolute: String::from(
-                fs::canonicalize("examples/assets/credits.md")
-                    .unwrap()
-                    .to_str()
-                    .unwrap(),
-            ),
+            relative: vec![String::from("assets"), String::from("credits.md")],
+            absolute: path::PathBuf::from(env::var("CARGO_MANIFEST_DIR").unwrap())
+                .join("examples")
+                .join("assets")
+                .join("credits.md")
+                .into_os_string()
+                .into_string()
+                .unwrap(),
         }];
         assert_eq!(actual, expected);
     }
