@@ -119,13 +119,14 @@ fn print_folder(context: &Context, name: &str, folder: &model::Folder) -> proc_m
 #[cfg(test)]
 mod tests {
     use super::*;
+    use std::array;
 
     #[test]
     fn handles_array() {
         let actual = main(
             &model::View {
                 type_: quote::format_ident!("Asset"),
-                forest: vec![
+                forest: array::IntoIter::new([
                     (
                         String::from('0'),
                         model::Tree::File(model::File {
@@ -136,20 +137,18 @@ mod tests {
                     (
                         String::from('1'),
                         model::Tree::Folder(model::Folder {
-                            forest: vec![(
+                            forest: array::IntoIter::new([(
                                 String::from('2'),
                                 model::Tree::File(model::File {
                                     relative_path: String::from("b/c"),
                                     ..model::stubs::file()
                                 }),
-                            )]
-                            .into_iter()
+                            )])
                             .collect(),
                             ..model::stubs::folder()
                         }),
                     ),
-                ]
-                .into_iter()
+                ])
                 .collect(),
                 ..model::stubs::view()
             },
@@ -193,7 +192,7 @@ mod tests {
             let actual = main(
                 &model::View {
                     type_: quote::format_ident!("Asset"),
-                    forest: vec![
+                    forest: array::IntoIter::new([
                         (
                             String::from('0'),
                             model::Tree::File(model::File {
@@ -210,8 +209,7 @@ mod tests {
                                 ..model::stubs::file()
                             }),
                         ),
-                    ]
-                    .into_iter()
+                    ])
                     .collect(),
                     ..model::stubs::view()
                 },
@@ -237,7 +235,7 @@ mod tests {
             let actual = main(
                 &model::View {
                     type_: quote::format_ident!("Asset"),
-                    forest: vec![
+                    forest: array::IntoIter::new([
                         (
                             String::from('0'),
                             model::Tree::File(model::File {
@@ -250,20 +248,19 @@ mod tests {
                             String::from('1'),
                             model::Tree::Folder(model::Folder {
                                 identifier: quote::format_ident!("b"),
-                                forest: vec![
+                                forest: array::IntoIter::new([
                                     (
                                         String::from('2'),
                                         model::Tree::Folder(model::Folder {
                                             identifier: quote::format_ident!("a"),
-                                            forest: vec![(
+                                            forest: array::IntoIter::new([(
                                                 String::from('3'),
                                                 model::Tree::File(model::File {
                                                     identifier: quote::format_ident!("B"),
                                                     index: 2,
                                                     ..model::stubs::file()
                                                 }),
-                                            )]
-                                            .into_iter()
+                                            )])
                                             .collect(),
                                         }),
                                     ),
@@ -275,13 +272,11 @@ mod tests {
                                             ..model::stubs::file()
                                         }),
                                     ),
-                                ]
-                                .into_iter()
+                                ])
                                 .collect(),
                             }),
                         ),
-                    ]
-                    .into_iter()
+                    ])
                     .collect(),
                     ..model::stubs::view()
                 },
@@ -321,7 +316,7 @@ mod tests {
         fn handles_with_options() {
             let actual = main(
                 &model::View {
-                    forest: vec![
+                    forest: array::IntoIter::new([
                         (
                             String::from('0'),
                             model::Tree::File(model::File {
@@ -335,12 +330,12 @@ mod tests {
                             String::from('1'),
                             model::Tree::Folder(model::Folder {
                                 identifier: quote::format_ident!("b"),
-                                forest: vec![
+                                forest: array::IntoIter::new([
                                     (
                                         String::from('2'),
                                         model::Tree::Folder(model::Folder {
                                             identifier: quote::format_ident!("a"),
-                                            forest: vec![(
+                                            forest: array::IntoIter::new([(
                                                 String::from('3'),
                                                 model::Tree::File(model::File {
                                                     identifier: quote::format_ident!("B"),
@@ -348,8 +343,7 @@ mod tests {
                                                     relative_path: String::from("b/a/b"),
                                                     absolute_path: String::from("/b/a/b"),
                                                 }),
-                                            )]
-                                            .into_iter()
+                                            )])
                                             .collect(),
                                         }),
                                     ),
@@ -362,13 +356,11 @@ mod tests {
                                             absolute_path: String::from("/b/c"),
                                         }),
                                     ),
-                                ]
-                                .into_iter()
+                                ])
                                 .collect(),
                             }),
                         ),
-                    ]
-                    .into_iter()
+                    ])
                     .collect(),
                     ..model::stubs::view()
                 },
@@ -404,11 +396,11 @@ mod tests {
         fn handles_without_visit_base() {
             let actual = main(
                 &model::View {
-                    forest: vec![(
+                    forest: array::IntoIter::new([(
                         String::from('0'),
                         model::Tree::Folder(model::Folder {
                             identifier: quote::format_ident!("a"),
-                            forest: vec![(
+                            forest: array::IntoIter::new([(
                                 String::from('1'),
                                 model::Tree::File(model::File {
                                     identifier: quote::format_ident!("B"),
@@ -416,12 +408,10 @@ mod tests {
                                     relative_path: String::from("a/b"),
                                     absolute_path: String::from("/a/b"),
                                 }),
-                            )]
-                            .into_iter()
+                            )])
                             .collect(),
                         }),
-                    )]
-                    .into_iter()
+                    )])
                     .collect(),
                     ..model::stubs::view()
                 },
@@ -448,11 +438,11 @@ mod tests {
         fn handles_without_visit_folder() {
             let actual = main(
                 &model::View {
-                    forest: vec![(
+                    forest: array::IntoIter::new([(
                         String::from('0'),
                         model::Tree::Folder(model::Folder {
                             identifier: quote::format_ident!("a"),
-                            forest: vec![(
+                            forest: array::IntoIter::new([(
                                 String::from('1'),
                                 model::Tree::File(model::File {
                                     identifier: quote::format_ident!("B"),
@@ -460,12 +450,10 @@ mod tests {
                                     relative_path: String::from("a/b"),
                                     absolute_path: String::from("/a/b"),
                                 }),
-                            )]
-                            .into_iter()
+                            )])
                             .collect(),
                         }),
-                    )]
-                    .into_iter()
+                    )])
                     .collect(),
                     ..model::stubs::view()
                 },
